@@ -131,7 +131,8 @@ static void my_log(void * unused,
   }
 }
 
-static int isPruned(const char * filename) {
+static int isPruned(const char * filename,
+		    void * cls) {
   int i;
   int last;
 
@@ -161,19 +162,20 @@ static int isPruned(const char * filename) {
  * @brief closure for do_index
  */
 typedef struct {
-  EXTRACTOR_ExtractorList * elist;
+  struct EXTRACT_Process * elist;
   struct DOODLE_SuffixTree * tree;
   FILE * logFile;
 } DIC;
 
 
 static int do_index(const char * filename,
-		    DIC * dic) {
+		    void * cls) {
+  DIC * dic = cls;
   int i;
   int j;
   struct stat sbuf;
 
-  if (isPruned(filename))
+  if (isPruned(filename, NULL))
     return 0;
   j = -1;
   for (i=DOODLE_getFileCount(dic->tree)-1;i>=0;i--)
@@ -197,6 +199,7 @@ static int do_index(const char * filename,
       printf(_("Processing '%s'\n"),
 	     filename);
     return buildIndex(dic->elist,
+		      dic->logFile,
 		      filename,
 		      dic->tree,
 		      do_filenames);
@@ -245,24 +248,10 @@ static int build(const char * libraries,
 			       &my_log,
 			       NULL);
 
-  if (do_default) {
-    if (verbose)
-      printf(_("Loading default set of libextractor plugins.\n"));
-    cls.elist = EXTRACTOR_loadDefaultLibraries();
-  } else
-    cls.elist = NULL;
-  if (libraries != NULL) {
-    if (verbose)
-      printf(_("Loading libextractor plugins: '%s'\n"),
-	     libraries);
-    cls.elist = EXTRACTOR_loadConfigLibraries(cls.elist,
-					      libraries);
-  }
-  if (cls.elist == NULL) {
-    printf(_("Failed to load any libextractor plugins. Aborting.\n"));
-    DOODLE_tree_destroy(cls.tree);
-    return -1;
-  }
+  cls.elist = forkExtractor(do_default,
+			    libraries,
+			    &my_log,
+			    NULL);
   cls.logFile = NULL;
   if (log != NULL) {
     cls.logFile = fopen(log, "w+");
@@ -283,7 +272,9 @@ static int build(const char * libraries,
     if (-1 == scanDirectory(exp,
 			    &my_log,
 			    NULL,
-			    (ScannerCallback) &do_index,
+			    &isPruned,
+			    NULL,
+			    &do_index,
 			    &cls)) {
       ret = -1;
       free(exp);
@@ -291,7 +282,7 @@ static int build(const char * libraries,
     }
     free(exp);
   }
-  EXTRACTOR_removeAll(cls.elist);
+  joinExtractor(cls.elist);  
   DOODLE_tree_destroy(cls.tree);
   if (cls.logFile != NULL)
     fclose(cls.logFile);
@@ -304,8 +295,8 @@ static int build(const char * libraries,
 typedef struct {
   EXTRACTOR_ExtractorList * list;
   char ** filenames_seen;
-  int seen_size;
-  int seen_count;
+  unsigned int seen_size;
+  unsigned int seen_count;
 } PrintItArgs;
 
 
@@ -318,7 +309,7 @@ static void printIt(const DOODLE_FileInfo * fileinfo,
   int i;
 
   filename = fileinfo->filename;
-  if (isPruned(filename))
+  if (isPruned(filename, NULL))
     return;
   for (i=args->seen_count-1;i>=0;i--)
     if (0 == strcmp(filename,
@@ -525,22 +516,22 @@ int main(int argc,
       {"database", 1, 0, 'd'},
       {"extract", 0, 0, 'e'},
       {"filenames", 0, 0, 'f'} ,
-      {"help", 0, 0, 'h'},
       {"hash", 1, 0, 'H'},
+      {"help", 0, 0, 'h'},
       {"ignore-case", 0, 0, 'i'},
       {"library", 1, 0, 'l'},
       {"log", 1, 0, 'L'},
       {"memory", 1, 0, 'm'},
       {"nodefault", 1, 0, 'n'},
-      {"print", 0, 0, 'p'},
       {"prunepaths", 1, 0, 'P' },
+      {"print", 0, 0, 'p'},
       {"verbose", 0, 0, 'V'},
       {"version", 0, 0, 'v'},
       {NULL, 0, 0, 0}
     };
     option_index = 0;
     c = getopt_long(argc,
-		    argv, "VvhbB:eH:nm:il:L:vd:fa:p",
+		    argv, "a:B:bd:efH:hil:L:m:nP:pVv",
 		    long_options,
 		    &option_index);
 
